@@ -34,19 +34,18 @@
 #include <locale.h>
 #include <libintl.h>
 /*******************************************************************************/
-#define APPLET_X_SIZE		200
-#define APPLET_Y_SIZE		40
-#define FONT_MAIN_SIZE_LARGE	14
-#define FONT_MAIN_SIZE_MEDIUM	12
-#define FONT_MAIN_SIZE_SMALL	10
-/*******************************************************************************/
-WDB* create_weather_day_button(const char *text, const char *icon, const int icon_size, gboolean transparency, char font_size);
+gboolean change_station_select(GtkWidget *widget, gpointer user_data);
+WDB* create_weather_day_button(const char *text, const char *icon,
+				const int icon_size, gboolean transparency,
+				char font_size, GdkColor *color);
 void delete_weather_day_button(gboolean after_all_destroy,WDB **day);
 void weather_buttons_init(void);
 void weather_buttons_fill(gboolean check_error);
 void weather_com_destroy_parser( weather_com_parser *weather_com );
 void update_weather(void);
 void set_font_size(GtkWidget *widget, char font_size);
+void set_font_color (GtkWidget *widget, guint16 red, guint16 green, guint16 blue);
+void set_background_color(GtkWidget *widget, GdkColor *bgc);
 void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* st_name, char f_size);
 weather_com_parser *weather_com_parser_new( const gchar * weather_com );
 int parse_weather_com_xml(void);
@@ -56,18 +55,31 @@ gboolean download_html(gpointer data);
 void update_weather(void);
 void free_memory(gboolean flag);
 void swap_temperature(int *hi, int *low);
-/* external functions */
+void station_error_window(void);
+void menu_init(void);
+void set_font_color(GtkWidget *widget, guint16 red, guint16 green, guint16 blue);
+void set_widget_background(GtkWidget *widget, guint16 red, guint16 green, guint16 blue);
+gboolean expose_main_window(GtkWidget *widget, GdkEventExpose *event);
+gboolean expose_parent(GtkWidget *widget, GdkEventExpose *event);
+gboolean remitted_update(void);
+/*******************************************************************************/
 extern void timer(int interval);
+extern void create_timer_with_interval(guint interval);
 extern void weather_initialize_dbus(void);
 extern void add_periodic_event(time_t last_update);
 extern void remove_daytime_event(void);
 extern void clean_download(void);
-/* List times between two updates */
-GSList *time_update_list = NULL;
-gboolean not_event = FALSE;
-int 	   boxs_offset [Max_count_weather_day];
-guint flag_update=0;
-gchar  path_large_icon[_POSIX_PATH_MAX];
+extern void weather_window_settings(GtkWidget *widget,GdkEvent *event,gpointer user_data);
+extern int new_read_config(AppletConfig*);
+extern void new_config_save(AppletConfig*);
+extern GtkListStore* create_items_list(const char *filename, long start, long end,
+					long *items_number);
+extern GtkListStore* create_time_update_list(void);
+extern void fill_station_from_clock_plugin_data(void);
+extern void reinitilize_stations_list2(GSList *stlist);
+/*******************************************************************************/
+extern int	boxs_offset[];
+extern gchar	path_large_icon[];
 /*******************************************************************************/
 typedef struct _HomeAppletHandler HomeAppletHandler;
 /*******************************************************************************/
@@ -86,4 +98,4 @@ struct _HomeAppletHandler {
     gint resizable_height;
 };
 /*******************************************************************************/
-#endif
+#endif
\ No newline at end of file
