@@ -78,6 +78,13 @@
 #define MOON_ICONS		"/usr/share/omweather/moon_icons/"
 #define GCONF_KEY_CURRENT_CONNECTIVITY	"/system/osso/connectivity/IAP/current"
 #define streq(a, b)   (*(a)==*(b)&&!strcmp(a,b))
+#define GIANT_ICON_SIZE  128
+#define LARGE_ICON_SIZE   96
+#define BIG_ICON_SIZE     80
+#define MEDIUM_ICON_SIZE  64
+#define SMALL_ICON_SIZE   48
+#define TINY_ICON_SIZE    32
+ 
 /*******************************************************************************/
 enum { AUTOUPDATE, DAYTIMEEVENT, DBUSINITEVENT, UPDATE_AFTER_CONNECTED};
 enum { ONE_ROW, ONE_COLUMN, TWO_ROWS, TWO_COLUMNS };
@@ -89,7 +96,7 @@ enum {	METERS_S,
 */	KILOMETERS_H,
 	MILES_H };
 enum { CELSIUS, FAHRENHEIT };
-enum { LARGE, MEDIUM, SMALL };
+enum {  GIANT, LARGE, MEDIUM, SMALL, TINY  };
 /*******************************************************************************/
 typedef struct{
     gchar	speed[80];		/* wind speed */
