@@ -201,6 +201,7 @@ int new_read_config(AppletConfig *config){
     gchar	tmp_buff[1024],
 		*home_dir,
 		*tmp = NULL;
+    float	version;
 
 #ifndef RELEASE
     fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
@@ -262,7 +263,7 @@ int new_read_config(AppletConfig *config){
     config->icons_size = gconf_client_get_int(gconf_client,
         				    GCONF_KEY_WEATHER_ICONS_SIZE,
 					    NULL);
-    if(config->icons_size < LARGE || config->icons_size > SMALL)
+    if(config->icons_size < GIANT || config->icons_size > TINY)
         config->icons_size = LARGE;
 
     /* Get setting tab number  */		     
@@ -426,6 +427,12 @@ int new_read_config(AppletConfig *config){
 	}	    
     }
     else{
+	/* Correcting icon size for version less 0.19.5. It  must be deleted after version 0.21 */
+	if (tmp[0]=='0' && tmp[2]<'2' && tmp[3]<='9' && tmp[5]<'5'){
+	    config->icons_size = config->icons_size + 2;
+	    if(config->icons_size < GIANT || config->icons_size > TINY)
+    		config->icons_size = LARGE;
+	}
 	g_free(tmp);		     
 	tmp = NULL;		
     }    
