@@ -777,14 +777,18 @@ void weather_window_settings(GtkWidget *widget,
         			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
         			1, 2, 3, 4);
     gtk_container_add(GTK_CONTAINER(label),icon_size = gtk_combo_box_new_text());
+    gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Giant"));    
     gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Large"));
     gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Medium"));
     gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Small"));
+    gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), _("Tiny"));
     switch(app->config->icons_size){
 	default:
-	case LARGE: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),0);break;
-	case MEDIUM: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),1);break;
-	case SMALL: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),2);break;
+	case GIANT: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),0);break;	
+	case LARGE: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),1);break;	
+	case MEDIUM: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),2);break;
+	case SMALL: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),3);break;
+	case TINY: gtk_combo_box_set_active(GTK_COMBO_BOX(icon_size),4);break;
     }
 /* Font color */   
     gtk_table_attach_defaults(GTK_TABLE(table),	    
@@ -1248,6 +1252,8 @@ void create_help_dialog(void){
     strcat(tmp_buff,
 	    _("Arkady Glazov aka Globster - for testing\n"
 	      "Alexander Savchenko aka dizel - for testing\n"));
+    strcat(tmp_buff,
+	    _("Eric Link - for feature request and donation\n"));
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
         			create_scrolled_window_with_text(tmp_buff,
 						    GTK_JUSTIFY_LEFT),
