@@ -418,7 +418,7 @@ GtkWidget* create_header_widget(int i){
     gtk_box_pack_start(GTK_BOX(location_button_hbox),
 				location_label, FALSE, FALSE, 0);
     gtk_box_pack_end(GTK_BOX(location_button_hbox),
-				button, FALSE, FALSE, 2);
+				button, FALSE, FALSE, 2);    
 /* prepare date label */
     date_hbox = gtk_hbox_new(FALSE, 0);
     if((i < Max_count_weather_day) && strcmp(app->weather_days[i].date, "") && strcmp(app->weather_days[i].dayfuname, "")){
@@ -522,7 +522,7 @@ GtkWidget* create_current_weather_widget(void){
     float	tmp_distance = 0;
 
     sprintf(buffer,"%s%i.png", path_large_icon, app->weather_current_day.day.icon);
-    icon = gdk_pixbuf_new_from_file_at_size(buffer, 64, 64,NULL);
+    icon = gdk_pixbuf_new_from_file_at_size(buffer, BIG_ICON_SIZE, BIG_ICON_SIZE, NULL);
     icon_image = gtk_image_new_from_pixbuf(icon);
     if(icon)
 	g_object_unref(icon);
@@ -602,7 +602,7 @@ GtkWidget* create_current_weather_widget(void){
 
     main_data_vbox = gtk_vbox_new(FALSE, 0);	
     main_data_label = gtk_label_new(buffer);
-    set_font_size(main_data_label, 14);
+    set_font_size(main_data_label, 17);
     set_font_color(main_data_label,0x0000,0x0000,0x0000);
     gtk_box_pack_start(GTK_BOX(main_data_vbox), main_data_label,
 			    FALSE, FALSE, 0);
@@ -674,11 +674,11 @@ GtkWidget* create_temperature_range_widget(int i){
 			"%d\302\260%c", hi_temp, symbol);
     /* prepare temperature hbox */
     temperature_value_label = gtk_label_new(buffer);
-    set_font_size(temperature_value_label, 16);
+    set_font_size(temperature_value_label, 18);
     set_font_color(temperature_value_label, 0x0000, 0x0000, 0x0000);
     main_widget = gtk_hbox_new(FALSE, 10);
     temperature_title_label = gtk_label_new(_("Temperature: "));
-    set_font_size(temperature_title_label, 14);
+    set_font_size(temperature_title_label, 16);
     gtk_box_pack_start(GTK_BOX(main_widget), temperature_title_label, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(main_widget), temperature_value_label, FALSE, FALSE, 0);
     return main_widget;
@@ -726,7 +726,7 @@ GtkWidget* create_24_hours_widget(int i){
 /* prepare night data */
     if(i < Max_count_weather_day){
 	sprintf(buffer, "%s%i.png", path_large_icon, app->weather_days[i].night.icon);
-	icon = gdk_pixbuf_new_from_file_at_size(buffer, 64, 64, NULL);
+	icon = gdk_pixbuf_new_from_file_at_size(buffer, BIG_ICON_SIZE, BIG_ICON_SIZE, NULL);
 	night_icon = gtk_image_new_from_pixbuf(icon);
     }	
     if(icon)
@@ -752,7 +752,7 @@ GtkWidget* create_24_hours_widget(int i){
 			convert_wind_units(app->config->wind_units, atof(app->weather_days[i].night.wind_speed)),
 			(char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units]));
     night_data_label = gtk_label_new(buffer);    
-    set_font_size(night_data_label, 14);
+    set_font_size(night_data_label, 17);
     set_font_color(night_data_label,0x0000,0x0000,0x0000);                
 /* prepare icon and label vbox */
     night_icon_label_vbox = gtk_vbox_new(FALSE, 0);
@@ -766,7 +766,7 @@ GtkWidget* create_24_hours_widget(int i){
 /* prepare day data */
     if(i < Max_count_weather_day){
 	sprintf(buffer, "%s%i.png", path_large_icon, app->weather_days[i].day.icon);
-        icon = gdk_pixbuf_new_from_file_at_size(buffer, 64, 64, NULL);
+        icon = gdk_pixbuf_new_from_file_at_size(buffer, BIG_ICON_SIZE, BIG_ICON_SIZE, NULL);
 	day_icon = gtk_image_new_from_pixbuf(icon);
     }	
     if(icon)
@@ -792,7 +792,7 @@ GtkWidget* create_24_hours_widget(int i){
 			convert_wind_units(app->config->wind_units, atof(app->weather_days[i].day.wind_speed)),
 			(char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units]));
     day_data_label = gtk_label_new(buffer);    
-    set_font_size(day_data_label, 14);
+    set_font_size(day_data_label, 17);
     set_font_color(day_data_label,0x0000,0x0000,0x0000);                
 /* prepare icon and label vbox */
     day_icon_label_vbox = gtk_vbox_new(FALSE, 0);
@@ -861,7 +861,7 @@ GtkWidget* create_sun_time_widget(int i){
 
 /* Sun icon */
     sprintf(icon, "%s32.png", path_large_icon);
-    icon_buffer = gdk_pixbuf_new_from_file_at_size(icon, 64, 64, NULL);
+    icon_buffer = gdk_pixbuf_new_from_file_at_size(icon, BIG_ICON_SIZE, BIG_ICON_SIZE, NULL);
     if(icon_buffer){
 	/* create Sun icon image from buffer */
 	icon_image = gtk_image_new_from_pixbuf(icon_buffer);
@@ -893,7 +893,7 @@ GtkWidget* create_sun_time_widget(int i){
 			"%X ", &time_show);
 
     main_label = gtk_label_new(buffer);
-    set_font_size(main_label, 14);
+    set_font_size(main_label, 17);
     set_font_color(main_label, 0x0000, 0x0000, 0x0000);
     main_widget = gtk_hbox_new(FALSE, 10);
     
@@ -922,7 +922,7 @@ GtkWidget* create_moon_phase_widget(void){
 			"%s",
 			(char*)hash_table_find((gpointer)app->weather_current_day.day.moon));
     main_label = gtk_label_new(buffer);
-    set_font_size(main_label, 14);
+    set_font_size(main_label, 17);
     set_font_color(main_label,0x0000,0x0000,0x0000);    
 
     main_widget = gtk_hbox_new(FALSE, 10);
@@ -930,7 +930,7 @@ GtkWidget* create_moon_phase_widget(void){
 /* Moon icon */
 /*    sprintf(icon, "%s%d.png", MOON_ICONS, app->weather_current_day.day.moon_icon);*/
     sprintf(icon, "%s31.png", path_large_icon);
-    icon_buffer = gdk_pixbuf_new_from_file_at_size(icon, 64, 64, NULL);
+    icon_buffer = gdk_pixbuf_new_from_file_at_size(icon, BIG_ICON_SIZE, BIG_ICON_SIZE, NULL);
     if(icon_buffer){
 	icon_image = gtk_image_new_from_pixbuf(icon_buffer);
 	g_object_unref(G_OBJECT(icon_buffer));
